@@ -34,7 +34,7 @@ SCRIPTS: Dict[str, str] = {
     'utils': from_file('utils.js'),
     'webgl_vendor': from_file('webgl.vendor.js'),
     'dimensions': from_file('window.dimensions.js'),
-    'user_agent_override': from_file('user-agent-override.js')
+    'user_agent_override': from_file('user-agent-override.js'),
 }
 
 
@@ -69,7 +69,7 @@ class StealthConfig:
     chrome_app: bool = False
     chrome_runtime: bool = False
     chrome_loadtimes: bool = False
-    webdriver: bool = False
+    webdriver: bool = True
     webgl_vendor: bool = True
     navigator_vendor: bool = True
     navigator_plugins: bool = True
@@ -86,9 +86,7 @@ class StealthConfig:
     nav_vendor: str = 'Apple Computer, Inc.'
     nav_platform: str = 'iPhone'
     nav_user_agent: str = None
-    languages: Tuple[str] = ('en-US', 'en')
     hardware_concurrency: int = -1
-    runOnInsecureOrigins: Optional[bool] = None
 
     @property
     def enabled_scripts(self):
@@ -98,16 +96,14 @@ class StealthConfig:
             'navigator_vendor': self.nav_vendor,
             'navigator_platform': self.nav_platform,
             'navigator_user_agent': self.nav_user_agent,
-            'languages': list(self.languages),
             'max_touch_points': self.max_touch_points,
             'hardwareConcurrency': self.hardware_concurrency,
-            'runOnInsecureOrigins': self.runOnInsecureOrigins,
         })
         # defined options constant
         yield f'const opts = {opts}'
         # init utils and magic-arrays helper
         yield SCRIPTS['utils']
-        yield SCRIPTS['magic-arrays']
+        # yield SCRIPTS['magic-arrays']
 
         if self.hairline:
             yield SCRIPTS['hairline']
@@ -153,6 +149,7 @@ def stealth_sync(page: SyncPage, config: StealthConfig = None):
         page.add_init_script(script)
 
 
-async def stealth_async(page: AsyncPage, logger: Logger):
-    for script in (StealthConfig()).enabled_scripts:
+async def stealth_async(page: AsyncPage, config: StealthConfig = None):
+    """teaches asynchronous playwright Page to be stealthy like a ninja!"""
+    for script in (config or StealthConfig()).enabled_scripts:
         await page.add_init_script(script)
\ No newline at end of file
